from PIL import Image
import img64

img_jpg = Image.open('sample.jpg').convert('RGB')
img_png = Image.open('sample.png').convert('RGB')
img_gray = Image.open('sample_grayscale.jpg').convert('L')

img64.base64_to_image(img64.image_to_base64(img_jpg), type="pil")
img64.base64_to_image(img64.image_to_base64(img_png), type="numpy")
img64.base64_to_image(img64.image_to_base64(img_gray), type="pil")
img64.base64_to_image(img64.image_to_base64(img_gray), type="numpy")




from setuptools import setup, find_packages

setup(
    name = 'img64',
    version = '0.0.2',
    description = "This library is a tool for converting images to base64 encoding and vice versa.",
    long_description = open('README.md', encoding='utf-8').read(),
    long_description_content_type = 'text/markdown',
    author = 'gibiee',
    author_email = 'gibiee@naver.com',
    url = 'https://github.com/gibiee/img64',
    download_url = '',
    packages = find_packages(exclude=[]),
    include_package_data = True,
    zip_safe = False,
    install_requires = ['pillow', 'numpy'],
    python_requires ='>=3',
    license = 'MIT',
    keywords = ['image', 'base64', 'image_base64'],
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ]
)


import io
import base64
import numpy as np
from PIL import Image
from typing import Union, Literal

def image_to_base64(img: Union[Image.Image, np.ndarray]) -> str :
    if isinstance(img, np.ndarray) :
        img = Image.fromarray(img)

    buffer = io.BytesIO()
    img.save(buffer, format="PNG")

    img_bytes = buffer.getvalue()
    img_b64 = base64.b64encode(img_bytes)
    img_b64_utf8 = img_b64.decode("utf-8")

    return img_b64_utf8

def base64_to_image(img_b64_utf8: str, type: Literal["pil", "numpy"]) -> Union[Image.Image, np.ndarray] :
    assert type in ["pil", "numpy"], "Expected type 'pil' or 'numpy'"
    img_bytes = base64.b64decode(img_b64_utf8)
    buffer = io.BytesIO(img_bytes)
    img = Image.open(buffer)

    if type == 'numpy' :
        img = np.array(img)

    return img